@@ -307,11 +307,11 @@ void AltVsTime::slotHighlight(void) {
 
 //move input focus to the next logical widget
 void AltVsTime::slotAdvanceFocus(void) {
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "nameBox" ) ) avtUI->addButton->setFocus();
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "raBox" ) ) avtUI->decBox->setFocus();
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "decbox" ) ) avtUI->addButton->setFocus();
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "longBox" ) ) avtUI->latBox->setFocus();
-	if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "latBox" ) ) avtUI->updateButton->setFocus();
+	if ( sender()->name() == TQString( "nameBox" ) ) avtUI->addButton->setFocus();
+	if ( sender()->name() == TQString( "raBox" ) ) avtUI->decBox->setFocus();
+	if ( sender()->name() == TQString( "decbox" ) ) avtUI->addButton->setFocus();
+	if ( sender()->name() == TQString( "longBox" ) ) avtUI->latBox->setFocus();
+	if ( sender()->name() == TQString( "latBox" ) ) avtUI->updateButton->setFocus();
 }
 
 void AltVsTime::slotClear(void) {
