@@ -30,7 +30,7 @@
 
 class GeneralOptions : public GeneralOptionsBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
