@@ -372,7 +372,7 @@ void ExtDateTimeEditor::init()
     setBackgroundMode( PaletteBase );
     setFocusSection( -1 );
     installEventFilter( this );
-    setFocusPolicy( TQ_WheelFocus );
+    setFocusPolicy( TQWidget::WheelFocus );
 }
 
 
@@ -474,7 +474,7 @@ void ExtDateTimeEditor::mousePressEvent( TQMouseEvent *e )
 */
 bool ExtDateTimeEditor::eventFilter( TQObject *o, TQEvent *e )
 {
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) ) {
+    if ( o == this ) {
 	if ( e->type() == TQEvent::KeyPress ) {
 	    TQKeyEvent *ke = (TQKeyEvent*)e;
 	    switch ( ke->key() ) {
